module Text.Numerals.Languages.GermanSpec (
    spec
  ) where

import Data.Text(Text)

import Test.Hspec(Spec)
import Text.Numerals.Languages.German(german)
import Text.Numerals.LanguageTest(testLanguage)

spec :: Spec
spec = testLanguage "German" german cardinals ordinals shortOrdinals

cardinals :: [(Integer, Text)]
cardinals = [
    (0, "null")
  , (1, "eins")
  , (2, "zwei")
  , (3, "drei")
  , (4, "vier")
  , (5, "fünf")
  , (6, "sechs")
  , (7, "sieben")
  , (8, "acht")
  , (9, "neun")
  , (10, "zehn")
  , (11, "elf")
  , (12, "zwölf")
  , (13, "dreizehn")
  , (14, "vierzehn")
  , (15, "fünfzehn")
  , (16, "sechzehn")
  , (17, "siebzehn")
  , (18, "achtzehn")
  , (19, "neunzehn")
  , (20, "zwanzig")
  , (21, "einundzwanzig")
  , (22, "zweiundzwanzig")
  , (23, "dreiundzwanzig")
  , (24, "vierundzwanzig")
  , (25, "fünfundzwanzig")
  , (26, "sechsundzwanzig")
  , (27, "siebenundzwanzig")
  , (28, "achtundzwanzig")
  , (29, "neunundzwanzig")
  , (30, "dreißig")
  , (31, "einunddreißig")
  , (32, "zweiunddreißig")
  , (33, "dreiunddreißig")
  , (34, "vierunddreißig")
  , (35, "fünfunddreißig")
  , (36, "sechsunddreißig")
  , (37, "siebenunddreißig")
  , (38, "achtunddreißig")
  , (39, "neununddreißig")
  , (40, "vierzig")
  , (41, "einundvierzig")
  , (42, "zweiundvierzig")
  , (43, "dreiundvierzig")
  , (44, "vierundvierzig")
  , (45, "fünfundvierzig")
  , (46, "sechsundvierzig")
  , (47, "siebenundvierzig")
  , (48, "achtundvierzig")
  , (49, "neunundvierzig")
  , (50, "fünfzig")
  , (51, "einundfünfzig")
  , (52, "zweiundfünfzig")
  , (53, "dreiundfünfzig")
  , (54, "vierundfünfzig")
  , (55, "fünfundfünfzig")
  , (56, "sechsundfünfzig")
  , (57, "siebenundfünfzig")
  , (58, "achtundfünfzig")
  , (59, "neunundfünfzig")
  , (60, "sechzig")
  , (61, "einundsechzig")
  , (62, "zweiundsechzig")
  , (63, "dreiundsechzig")
  , (64, "vierundsechzig")
  , (65, "fünfundsechzig")
  , (66, "sechsundsechzig")
  , (67, "siebenundsechzig")
  , (68, "achtundsechzig")
  , (69, "neunundsechzig")
  , (70, "siebzig")
  , (71, "einundsiebzig")
  , (72, "zweiundsiebzig")
  , (73, "dreiundsiebzig")
  , (74, "vierundsiebzig")
  , (75, "fünfundsiebzig")
  , (76, "sechsundsiebzig")
  , (77, "siebenundsiebzig")
  , (78, "achtundsiebzig")
  , (79, "neunundsiebzig")
  , (80, "achtzig")
  , (81, "einundachtzig")
  , (82, "zweiundachtzig")
  , (83, "dreiundachtzig")
  , (84, "vierundachtzig")
  , (85, "fünfundachtzig")
  , (86, "sechsundachtzig")
  , (87, "siebenundachtzig")
  , (88, "achtundachtzig")
  , (89, "neunundachtzig")
  , (90, "neunzig")
  , (91, "einundneunzig")
  , (92, "zweiundneunzig")
  , (93, "dreiundneunzig")
  , (94, "vierundneunzig")
  , (95, "fünfundneunzig")
  , (96, "sechsundneunzig")
  , (97, "siebenundneunzig")
  , (98, "achtundneunzig")
  , (99, "neunundneunzig")
  , (100, "einhundert")
  , (101, "einhunderteins")
  , (102, "einhundertzwei")
  , (103, "einhundertdrei")
  , (104, "einhundertvier")
  , (105, "einhundertfünf")
  , (106, "einhundertsechs")
  , (107, "einhundertsieben")
  , (108, "einhundertacht")
  , (109, "einhundertneun")
  , (110, "einhundertzehn")
  , (111, "einhundertelf")
  , (112, "einhundertzwölf")
  , (113, "einhundertdreizehn")
  , (114, "einhundertvierzehn")
  , (115, "einhundertfünfzehn")
  , (116, "einhundertsechzehn")
  , (117, "einhundertsiebzehn")
  , (118, "einhundertachtzehn")
  , (119, "einhundertneunzehn")
  , (120, "einhundertzwanzig")
  , (121, "einhunderteinundzwanzig")
  , (122, "einhundertzweiundzwanzig")
  , (123, "einhundertdreiundzwanzig")
  , (124, "einhundertvierundzwanzig")
  , (125, "einhundertfünfundzwanzig")
  , (126, "einhundertsechsundzwanzig")
  , (127, "einhundertsiebenundzwanzig")
  , (128, "einhundertachtundzwanzig")
  , (129, "einhundertneunundzwanzig")
  , (130, "einhundertdreißig")
  , (131, "einhunderteinunddreißig")
  , (132, "einhundertzweiunddreißig")
  , (133, "einhundertdreiunddreißig")
  , (134, "einhundertvierunddreißig")
  , (135, "einhundertfünfunddreißig")
  , (136, "einhundertsechsunddreißig")
  , (137, "einhundertsiebenunddreißig")
  , (138, "einhundertachtunddreißig")
  , (139, "einhundertneununddreißig")
  , (140, "einhundertvierzig")
  , (141, "einhunderteinundvierzig")
  , (142, "einhundertzweiundvierzig")
  , (143, "einhundertdreiundvierzig")
  , (144, "einhundertvierundvierzig")
  , (145, "einhundertfünfundvierzig")
  , (146, "einhundertsechsundvierzig")
  , (147, "einhundertsiebenundvierzig")
  , (148, "einhundertachtundvierzig")
  , (149, "einhundertneunundvierzig")
  , (150, "einhundertfünfzig")
  , (151, "einhunderteinundfünfzig")
  , (152, "einhundertzweiundfünfzig")
  , (153, "einhundertdreiundfünfzig")
  , (154, "einhundertvierundfünfzig")
  , (155, "einhundertfünfundfünfzig")
  , (156, "einhundertsechsundfünfzig")
  , (157, "einhundertsiebenundfünfzig")
  , (158, "einhundertachtundfünfzig")
  , (159, "einhundertneunundfünfzig")
  , (160, "einhundertsechzig")
  , (161, "einhunderteinundsechzig")
  , (162, "einhundertzweiundsechzig")
  , (163, "einhundertdreiundsechzig")
  , (164, "einhundertvierundsechzig")
  , (165, "einhundertfünfundsechzig")
  , (166, "einhundertsechsundsechzig")
  , (167, "einhundertsiebenundsechzig")
  , (168, "einhundertachtundsechzig")
  , (169, "einhundertneunundsechzig")
  , (170, "einhundertsiebzig")
  , (171, "einhunderteinundsiebzig")
  , (172, "einhundertzweiundsiebzig")
  , (173, "einhundertdreiundsiebzig")
  , (174, "einhundertvierundsiebzig")
  , (175, "einhundertfünfundsiebzig")
  , (176, "einhundertsechsundsiebzig")
  , (177, "einhundertsiebenundsiebzig")
  , (178, "einhundertachtundsiebzig")
  , (179, "einhundertneunundsiebzig")
  , (180, "einhundertachtzig")
  , (181, "einhunderteinundachtzig")
  , (182, "einhundertzweiundachtzig")
  , (183, "einhundertdreiundachtzig")
  , (184, "einhundertvierundachtzig")
  , (185, "einhundertfünfundachtzig")
  , (186, "einhundertsechsundachtzig")
  , (187, "einhundertsiebenundachtzig")
  , (188, "einhundertachtundachtzig")
  , (189, "einhundertneunundachtzig")
  , (190, "einhundertneunzig")
  , (191, "einhunderteinundneunzig")
  , (192, "einhundertzweiundneunzig")
  , (193, "einhundertdreiundneunzig")
  , (194, "einhundertvierundneunzig")
  , (195, "einhundertfünfundneunzig")
  , (196, "einhundertsechsundneunzig")
  , (197, "einhundertsiebenundneunzig")
  , (198, "einhundertachtundneunzig")
  , (199, "einhundertneunundneunzig")
  , (200, "zweihundert")
  , (233, "zweihundertdreiunddreißig")
  , (377, "dreihundertsiebenundsiebzig")
  , (610, "sechshundertzehn")
  , (987, "neunhundertsiebenundachtzig")
  , (1597, "eintausendfünfhundertsiebenundneunzig")
  , (2584, "zweitausendfünfhundertvierundachtzig")
  , (4181, "viertausendeinhunderteinundachtzig")
  , (6765, "sechstausendsiebenhundertfünfundsechzig")
  , (10946, "zehntausendneunhundertsechsundvierzig")
  , (17711, "siebzehntausendsiebenhundertelf")
  , (28657, "achtundzwanzigtausendsechshundertsiebenundfünfzig")
  , (46368, "sechsundvierzigtausenddreihundertachtundsechzig")
  , (75025, "fünfundsiebzigtausendfünfundzwanzig")
  , (121393, "einhunderteinundzwanzigtausenddreihundertdreiundneunzig")
  , (196418, "einhundertsechsundneunzigtausendvierhundertachtzehn")
  , (317811, "dreihundertsiebzehntausendachthundertelf")
  , (514229, "fünfhundertvierzehntausendzweihundertneunundzwanzig")
  , (832040, "achthundertzweiunddreißigtausendvierzig")
  , (1346269, "eine Million dreihundertsechsundvierzigtausendzweihundertneunundsechzig")
  , (2178309, "zwei Millionen einhundertachtundsiebzigtausenddreihundertneun")
  , (3524578, "drei Millionen fünfhundertvierundzwanzigtausendfünfhundertachtundsiebzig")
  , (5702887, "fünf Millionen siebenhundertzweitausendachthundertsiebenundachtzig")
  , (9227465, "neun Millionen zweihundertsiebenundzwanzigtausendvierhundertfünfundsechzig")
  , (14930352, "vierzehn Millionen neunhundertdreißigtausenddreihundertzweiundfünfzig")
  , (24157817, "vierundzwanzig Millionen einhundertsiebenundfünfzigtausendachthundertsiebzehn")
  , (39088169, "neununddreißig Millionen achtundachtzigtausendeinhundertneunundsechzig")
  , (63245986, "dreiundsechzig Millionen zweihundertfünfundvierzigtausendneunhundertsechsundachtzig")
  , (102334155, "einhundertzwei Millionen dreihundertvierunddreißigtausendeinhundertfünfundfünfzig")
  , (165580141, "einhundertfünfundsechzig Millionen fünfhundertachtzigtausendeinhunderteinundvierzig")
  , (267914296, "zweihundertsiebenundsechzig Millionen neunhundertvierzehntausendzweihundertsechsundneunzig")
  , (433494437, "vierhundertdreiunddreißig Millionen vierhundertvierundneunzigtausendvierhundertsiebenunddreißig")
  , (701408733, "siebenhunderteins Millionen vierhundertachttausendsiebenhundertdreiunddreißig")
  , (1134903170, "eine Milliard einhundertvierunddreißig Millionen neunhundertdreitausendeinhundertsiebzig")
  , (1836311903, "eine Milliard achthundertsechsunddreißig Millionen dreihundertelftausendneunhundertdrei")
  , (2971215073, "zwei Milliarden neunhunderteinundsiebzig Millionen zweihundertfünfzehntausenddreiundsiebzig")
  , (4807526976, "vier Milliarden achthundertsieben Millionen fünfhundertsechsundzwanzigtausendneunhundertsechsundsiebzig")
  , (7778742049, "sieben Milliarden siebenhundertachtundsiebzig Millionen siebenhundertzweiundvierzigtausendneunundvierzig")
  , (12586269025, "zwölf Milliarden fünfhundertsechsundachtzig Millionen zweihundertneunundsechzigtausendfünfundzwanzig")
  , (20365011074, "zwanzig Milliarden dreihundertfünfundsechzig Millionen elftausendvierundsiebzig")
  , (32951280099, "zweiunddreißig Milliarden neunhunderteinundfünfzig Millionen zweihundertachtzigtausendneunundneunzig")
  , (53316291173, "dreiundfünfzig Milliarden dreihundertsechzehn Millionen zweihunderteinundneunzigtausendeinhundertdreiundsiebzig")
  , (86267571272, "sechsundachtzig Milliarden zweihundertsiebenundsechzig Millionen fünfhunderteinundsiebzigtausendzweihundertzweiundsiebzig")
  , (139583862445, "einhundertneununddreißig Milliarden fünfhundertdreiundachtzig Millionen achthundertzweiundsechzigtausendvierhundertfünfundvierzig")
  , (225851433717, "zweihundertfünfundzwanzig Milliarden achthunderteinundfünfzig Millionen vierhundertdreiunddreißigtausendsiebenhundertsiebzehn")
  , (365435296162, "dreihundertfünfundsechzig Milliarden vierhundertfünfunddreißig Millionen zweihundertsechsundneunzigtausendeinhundertzweiundsechzig")
  , (591286729879, "fünfhunderteinundneunzig Milliarden zweihundertsechsundachtzig Millionen siebenhundertneunundzwanzigtausendachthundertneunundsiebzig")
  , (956722026041, "neunhundertsechsundfünfzig Milliarden siebenhundertzweiundzwanzig Millionen sechsundzwanzigtausendeinundvierzig")
  , (1548008755920, "eine Billion fünfhundertachtundvierzig Milliarden acht Millionen siebenhundertfünfundfünfzigtausendneunhundertzwanzig")
  , (2504730781961, "zwei Billionen fünfhundertvier Milliarden siebenhundertdreißig Millionen siebenhunderteinundachtzigtausendneunhunderteinundsechzig")
  , (4052739537881, "vier Billionen zweiundfünfzig Milliarden siebenhundertneununddreißig Millionen fünfhundertsiebenunddreißigtausendachthunderteinundachtzig")
  , (6557470319842, "sechs Billionen fünfhundertsiebenundfünfzig Milliarden vierhundertsiebzig Millionen dreihundertneunzehntausendachthundertzweiundvierzig")
  , (10610209857723, "zehn Billionen sechshundertzehn Milliarden zweihundertneun Millionen achthundertsiebenundfünfzigtausendsiebenhundertdreiundzwanzig")
  , (17167680177565, "siebzehn Billionen einhundertsiebenundsechzig Milliarden sechshundertachtzig Millionen einhundertsiebenundsiebzigtausendfünfhundertfünfundsechzig")
  , (27777890035288, "siebenundzwanzig Billionen siebenhundertsiebenundsiebzig Milliarden achthundertneunzig Millionen fünfunddreißigtausendzweihundertachtundachtzig")
  , (44945570212853, "vierundvierzig Billionen neunhundertfünfundvierzig Milliarden fünfhundertsiebzig Millionen zweihundertzwölftausendachthundertdreiundfünfzig")
  , (72723460248141, "zweiundsiebzig Billionen siebenhundertdreiundzwanzig Milliarden vierhundertsechzig Millionen zweihundertachtundvierzigtausendeinhunderteinundvierzig")
  , (117669030460994, "einhundertsiebzehn Billionen sechshundertneunundsechzig Milliarden dreißig Millionen vierhundertsechzigtausendneunhundertvierundneunzig")
  , (190392490709135, "einhundertneunzig Billionen dreihundertzweiundneunzig Milliarden vierhundertneunzig Millionen siebenhundertneuntausendeinhundertfünfunddreißig")
  , (308061521170129, "dreihundertacht Billionen einundsechzig Milliarden fünfhunderteinundzwanzig Millionen einhundertsiebzigtausendeinhundertneunundzwanzig")
  , (498454011879264, "vierhundertachtundneunzig Billionen vierhundertvierundfünfzig Milliarden elf Millionen achthundertneunundsiebzigtausendzweihundertvierundsechzig")
  , (806515533049393, "achthundertsechs Billionen fünfhundertfünfzehn Milliarden fünfhundertdreiunddreißig Millionen neunundvierzigtausenddreihundertdreiundneunzig")
  , (1304969544928657, "eine Billiard dreihundertvier Billionen neunhundertneunundsechzig Milliarden fünfhundertvierundvierzig Millionen neunhundertachtundzwanzigtausendsechshundertsiebenundfünfzig")
  , (2111485077978050, "zwei Billiarden einhundertelf Billionen vierhundertfünfundachtzig Milliarden siebenundsiebzig Millionen neunhundertachtundsiebzigtausendfünfzig")
  , (3416454622906707, "drei Billiarden vierhundertsechzehn Billionen vierhundertvierundfünfzig Milliarden sechshundertzweiundzwanzig Millionen neunhundertsechstausendsiebenhundertsieben")
  , (5527939700884757, "fünf Billiarden fünfhundertsiebenundzwanzig Billionen neunhundertneununddreißig Milliarden siebenhundert Millionen achthundertvierundachtzigtausendsiebenhundertsiebenundfünfzig")
  , (8944394323791464, "acht Billiarden neunhundertvierundvierzig Billionen dreihundertvierundneunzig Milliarden dreihundertdreiundzwanzig Millionen siebenhunderteinundneunzigtausendvierhundertvierundsechzig")
  , (14472334024676221, "vierzehn Billiarden vierhundertzweiundsiebzig Billionen dreihundertvierunddreißig Milliarden vierundzwanzig Millionen sechshundertsechsundsiebzigtausendzweihunderteinundzwanzig")
  , (23416728348467685, "dreiundzwanzig Billiarden vierhundertsechzehn Billionen siebenhundertachtundzwanzig Milliarden dreihundertachtundvierzig Millionen vierhundertsiebenundsechzigtausendsechshundertfünfundachtzig")
  , (37889062373143906, "siebenunddreißig Billiarden achthundertneunundachtzig Billionen zweiundsechzig Milliarden dreihundertdreiundsiebzig Millionen einhundertdreiundvierzigtausendneunhundertsechs")
  , (61305790721611591, "einundsechzig Billiarden dreihundertfünf Billionen siebenhundertneunzig Milliarden siebenhunderteinundzwanzig Millionen sechshundertelftausendfünfhunderteinundneunzig")
  , (99194853094755497, "neunundneunzig Billiarden einhundertvierundneunzig Billionen achthundertdreiundfünfzig Milliarden vierundneunzig Millionen siebenhundertfünfundfünfzigtausendvierhundertsiebenundneunzig")
  , (160500643816367088, "einhundertsechzig Billiarden fünfhundert Billionen sechshundertdreiundvierzig Milliarden achthundertsechzehn Millionen dreihundertsiebenundsechzigtausendachtundachtzig")
  , (259695496911122585, "zweihundertneunundfünfzig Billiarden sechshundertfünfundneunzig Billionen vierhundertsechsundneunzig Milliarden neunhundertelf Millionen einhundertzweiundzwanzigtausendfünfhundertfünfundachtzig")
  , (420196140727489673, "vierhundertzwanzig Billiarden einhundertsechsundneunzig Billionen einhundertvierzig Milliarden siebenhundertsiebenundzwanzig Millionen vierhundertneunundachtzigtausendsechshundertdreiundsiebzig")
  , (679891637638612258, "sechshundertneunundsiebzig Billiarden achthunderteinundneunzig Billionen sechshundertsiebenunddreißig Milliarden sechshundertachtunddreißig Millionen sechshundertzwölftausendzweihundertachtundfünfzig")
  , (1100087778366101931, "eine Trillion einhundert Billiarden siebenundachtzig Billionen siebenhundertachtundsiebzig Milliarden dreihundertsechsundsechzig Millionen einhunderteinstausendneunhunderteinunddreißig")
  , (1779979416004714189, "eine Trillion siebenhundertneunundsiebzig Billiarden neunhundertneunundsiebzig Billionen vierhundertsechzehn Milliarden vier Millionen siebenhundertvierzehntausendeinhundertneunundachtzig")
  , (2880067194370816120, "zwei Trillionen achthundertachtzig Billiarden siebenundsechzig Billionen einhundertvierundneunzig Milliarden dreihundertsiebzig Millionen achthundertsechzehntausendeinhundertzwanzig")
  , (4660046610375530309, "vier Trillionen sechshundertsechzig Billiarden sechsundvierzig Billionen sechshundertzehn Milliarden dreihundertfünfundsiebzig Millionen fünfhundertdreißigtausenddreihundertneun")
  , (7540113804746346429, "sieben Trillionen fünfhundertvierzig Billiarden einhundertdreizehn Billionen achthundertvier Milliarden siebenhundertsechsundvierzig Millionen dreihundertsechsundvierzigtausendvierhundertneunundzwanzig")
  , (12200160415121876738, "zwölf Trillionen zweihundert Billiarden einhundertsechzig Billionen vierhundertfünfzehn Milliarden einhunderteinundzwanzig Millionen achthundertsechsundsiebzigtausendsiebenhundertachtunddreißig")
  , (19740274219868223167, "neunzehn Trillionen siebenhundertvierzig Billiarden zweihundertvierundsiebzig Billionen zweihundertneunzehn Milliarden achthundertachtundsechzig Millionen zweihundertdreiundzwanzigtausendeinhundertsiebenundsechzig")
  , (31940434634990099905, "einunddreißig Trillionen neunhundertvierzig Billiarden vierhundertvierunddreißig Billionen sechshundertvierunddreißig Milliarden neunhundertneunzig Millionen neunundneunzigtausendneunhundertfünf")
  , (51680708854858323072, "einundfünfzig Trillionen sechshundertachtzig Billiarden siebenhundertacht Billionen achthundertvierundfünfzig Milliarden achthundertachtundfünfzig Millionen dreihundertdreiundzwanzigtausendzweiundsiebzig")
  , (83621143489848422977, "dreiundachtzig Trillionen sechshunderteinundzwanzig Billiarden einhundertdreiundvierzig Billionen vierhundertneunundachtzig Milliarden achthundertachtundvierzig Millionen vierhundertzweiundzwanzigtausendneunhundertsiebenundsiebzig")
  , (135301852344706746049, "einhundertfünfunddreißig Trillionen dreihunderteins Billiarden achthundertzweiundfünfzig Billionen dreihundertvierundvierzig Milliarden siebenhundertsechs Millionen siebenhundertsechsundvierzigtausendneunundvierzig")
  , (218922995834555169026, "zweihundertachtzehn Trillionen neunhundertzweiundzwanzig Billiarden neunhundertfünfundneunzig Billionen achthundertvierunddreißig Milliarden fünfhundertfünfundfünfzig Millionen einhundertneunundsechzigtausendsechsundzwanzig")
  , (354224848179261915075, "dreihundertvierundfünfzig Trillionen zweihundertvierundzwanzig Billiarden achthundertachtundvierzig Billionen einhundertneunundsiebzig Milliarden zweihunderteinundsechzig Millionen neunhundertfünfzehntausendfünfundsiebzig")
  , (573147844013817084101, "fünfhundertdreiundsiebzig Trillionen einhundertsiebenundvierzig Billiarden achthundertvierundvierzig Billionen dreizehn Milliarden achthundertsiebzehn Millionen vierundachtzigtausendeinhunderteins")
  , (927372692193078999176, "neunhundertsiebenundzwanzig Trillionen dreihundertzweiundsiebzig Billiarden sechshundertzweiundneunzig Billionen einhundertdreiundneunzig Milliarden achtundsiebzig Millionen neunhundertneunundneunzigtausendeinhundertsechsundsiebzig")
  , (1500520536206896083277, "eine Trilliard fünfhundert Trillionen fünfhundertzwanzig Billiarden fünfhundertsechsunddreißig Billionen zweihundertsechs Milliarden achthundertsechsundneunzig Millionen dreiundachtzigtausendzweihundertsiebenundsiebzig")
  , (2427893228399975082453, "zwei Trilliarden vierhundertsiebenundzwanzig Trillionen achthundertdreiundneunzig Billiarden zweihundertachtundzwanzig Billionen dreihundertneunundneunzig Milliarden neunhundertfünfundsiebzig Millionen zweiundachtzigtausendvierhundertdreiundfünfzig")
  , (3928413764606871165730, "drei Trilliarden neunhundertachtundzwanzig Trillionen vierhundertdreizehn Billiarden siebenhundertvierundsechzig Billionen sechshundertsechs Milliarden achthunderteinundsiebzig Millionen einhundertfünfundsechzigtausendsiebenhundertdreißig")
  , (6356306993006846248183, "sechs Trilliarden dreihundertsechsundfünfzig Trillionen dreihundertsechs Billiarden neunhundertdreiundneunzig Billionen sechs Milliarden achthundertsechsundvierzig Millionen zweihundertachtundvierzigtausendeinhundertdreiundachtzig")
  , (10284720757613717413913, "zehn Trilliarden zweihundertvierundachtzig Trillionen siebenhundertzwanzig Billiarden siebenhundertsiebenundfünfzig Billionen sechshundertdreizehn Milliarden siebenhundertsiebzehn Millionen vierhundertdreizehntausendneunhundertdreizehn")
  , (16641027750620563662096, "sechzehn Trilliarden sechshunderteinundvierzig Trillionen siebenundzwanzig Billiarden siebenhundertfünfzig Billionen sechshundertzwanzig Milliarden fünfhundertdreiundsechzig Millionen sechshundertzweiundsechzigtausendsechsundneunzig")
  , (26925748508234281076009, "sechsundzwanzig Trilliarden neunhundertfünfundzwanzig Trillionen siebenhundertachtundvierzig Billiarden fünfhundertacht Billionen zweihundertvierunddreißig Milliarden zweihunderteinundachtzig Millionen sechsundsiebzigtausendneun")
  , (43566776258854844738105, "dreiundvierzig Trilliarden fünfhundertsechsundsechzig Trillionen siebenhundertsechsundsiebzig Billiarden zweihundertachtundfünfzig Billionen achthundertvierundfünfzig Milliarden achthundertvierundvierzig Millionen siebenhundertachtunddreißigtausendeinhundertfünf")
  , (70492524767089125814114, "siebzig Trilliarden vierhundertzweiundneunzig Trillionen fünfhundertvierundzwanzig Billiarden siebenhundertsiebenundsechzig Billionen neunundachtzig Milliarden einhundertfünfundzwanzig Millionen achthundertvierzehntausendeinhundertvierzehn")
  , (114059301025943970552219, "einhundertvierzehn Trilliarden neunundfünfzig Trillionen dreihunderteins Billiarden fünfundzwanzig Billionen neunhundertdreiundvierzig Milliarden neunhundertsiebzig Millionen fünfhundertzweiundfünfzigtausendzweihundertneunzehn")
  , (1000, "eintausend")
  , (10000, "zehntausend")
  , (100000, "einhunderttausend")
  , (1000000, "eine Million")
  , (10000000, "zehn Millionen")
  , (100000000, "einhundert Millionen")
  , (1000000000, "eine Milliard")
  , (10000000000, "zehn Milliarden")
  , (100000000000, "einhundert Milliarden")
  , (1000000000000, "eine Billion")
  , (10000000000000, "zehn Billionen")
  , (100000000000000, "einhundert Billionen")
  , (1000000000000000, "eine Billiard")
  , (10000000000000000, "zehn Billiarden")
  , (100000000000000000, "einhundert Billiarden")
  , (1000000000000000000, "eine Trillion")
  , (10000000000000000000, "zehn Trillionen")
  , (100000000000000000000, "einhundert Trillionen")
  , (1000000000000000000000, "eine Trilliard")
  , (10000000000000000000000, "zehn Trilliarden")
  , (100000000000000000000000, "einhundert Trilliarden")
  , (1000000000000000000000000, "eine Quadrillion")
  ]

ordinals :: [(Integer, Text)]
ordinals = [
    (0, "nullte")
  , (1, "erste")
  , (2, "zweite")
  , (3, "dritte")
  , (4, "vierte")
  , (5, "fünfte")
  , (6, "sechste")
  , (7, "siebte")
  , (8, "achte")
  , (9, "neunte")
  , (10, "zehnte")
  , (11, "elfte")
  , (12, "zwölfte")
  , (13, "dreizehnte")
  , (14, "vierzehnte")
  , (15, "fünfzehnte")
  , (16, "sechzehnte")
  , (17, "siebzehnte")
  , (18, "achtzehnte")
  , (19, "neunzehnte")
  , (20, "zwanzigste")
  , (21, "einundzwanzigste")
  , (22, "zweiundzwanzigste")
  , (23, "dreiundzwanzigste")
  , (24, "vierundzwanzigste")
  , (25, "fünfundzwanzigste")
  , (26, "sechsundzwanzigste")
  , (27, "siebenundzwanzigste")
  , (28, "achtundzwanzigste")
  , (29, "neunundzwanzigste")
  , (30, "dreißigste")
  , (31, "einunddreißigste")
  , (32, "zweiunddreißigste")
  , (33, "dreiunddreißigste")
  , (34, "vierunddreißigste")
  , (35, "fünfunddreißigste")
  , (36, "sechsunddreißigste")
  , (37, "siebenunddreißigste")
  , (38, "achtunddreißigste")
  , (39, "neununddreißigste")
  , (40, "vierzigste")
  , (41, "einundvierzigste")
  , (42, "zweiundvierzigste")
  , (43, "dreiundvierzigste")
  , (44, "vierundvierzigste")
  , (45, "fünfundvierzigste")
  , (46, "sechsundvierzigste")
  , (47, "siebenundvierzigste")
  , (48, "achtundvierzigste")
  , (49, "neunundvierzigste")
  , (50, "fünfzigste")
  , (51, "einundfünfzigste")
  , (52, "zweiundfünfzigste")
  , (53, "dreiundfünfzigste")
  , (54, "vierundfünfzigste")
  , (55, "fünfundfünfzigste")
  , (56, "sechsundfünfzigste")
  , (57, "siebenundfünfzigste")
  , (58, "achtundfünfzigste")
  , (59, "neunundfünfzigste")
  , (60, "sechzigste")
  , (61, "einundsechzigste")
  , (62, "zweiundsechzigste")
  , (63, "dreiundsechzigste")
  , (64, "vierundsechzigste")
  , (65, "fünfundsechzigste")
  , (66, "sechsundsechzigste")
  , (67, "siebenundsechzigste")
  , (68, "achtundsechzigste")
  , (69, "neunundsechzigste")
  , (70, "siebzigste")
  , (71, "einundsiebzigste")
  , (72, "zweiundsiebzigste")
  , (73, "dreiundsiebzigste")
  , (74, "vierundsiebzigste")
  , (75, "fünfundsiebzigste")
  , (76, "sechsundsiebzigste")
  , (77, "siebenundsiebzigste")
  , (78, "achtundsiebzigste")
  , (79, "neunundsiebzigste")
  , (80, "achtzigste")
  , (81, "einundachtzigste")
  , (82, "zweiundachtzigste")
  , (83, "dreiundachtzigste")
  , (84, "vierundachtzigste")
  , (85, "fünfundachtzigste")
  , (86, "sechsundachtzigste")
  , (87, "siebenundachtzigste")
  , (88, "achtundachtzigste")
  , (89, "neunundachtzigste")
  , (90, "neunzigste")
  , (91, "einundneunzigste")
  , (92, "zweiundneunzigste")
  , (93, "dreiundneunzigste")
  , (94, "vierundneunzigste")
  , (95, "fünfundneunzigste")
  , (96, "sechsundneunzigste")
  , (97, "siebenundneunzigste")
  , (98, "achtundneunzigste")
  , (99, "neunundneunzigste")
  , (100, "hundertste")
  , (101, "einhunderterste")
  , (102, "einhundertzweite")
  , (103, "einhundertdritte")
  , (104, "einhundertvierte")
  , (105, "einhundertfünfte")
  , (106, "einhundertsechste")
  , (107, "einhundertsiebte")
  , (108, "einhundertachte")
  , (109, "einhundertneunte")
  , (110, "einhundertzehnte")
  , (111, "einhundertelfte")
  , (112, "einhundertzwölfte")
  , (113, "einhundertdreizehnte")
  , (114, "einhundertvierzehnte")
  , (115, "einhundertfünfzehnte")
  , (116, "einhundertsechzehnte")
  , (117, "einhundertsiebzehnte")
  , (118, "einhundertachtzehnte")
  , (119, "einhundertneunzehnte")
  , (120, "einhundertzwanzigste")
  , (121, "einhunderteinundzwanzigste")
  , (122, "einhundertzweiundzwanzigste")
  , (123, "einhundertdreiundzwanzigste")
  , (124, "einhundertvierundzwanzigste")
  , (125, "einhundertfünfundzwanzigste")
  , (126, "einhundertsechsundzwanzigste")
  , (127, "einhundertsiebenundzwanzigste")
  , (128, "einhundertachtundzwanzigste")
  , (129, "einhundertneunundzwanzigste")
  , (130, "einhundertdreißigste")
  , (131, "einhunderteinunddreißigste")
  , (132, "einhundertzweiunddreißigste")
  , (133, "einhundertdreiunddreißigste")
  , (134, "einhundertvierunddreißigste")
  , (135, "einhundertfünfunddreißigste")
  , (136, "einhundertsechsunddreißigste")
  , (137, "einhundertsiebenunddreißigste")
  , (138, "einhundertachtunddreißigste")
  , (139, "einhundertneununddreißigste")
  , (140, "einhundertvierzigste")
  , (141, "einhunderteinundvierzigste")
  , (142, "einhundertzweiundvierzigste")
  , (143, "einhundertdreiundvierzigste")
  , (144, "einhundertvierundvierzigste")
  , (145, "einhundertfünfundvierzigste")
  , (146, "einhundertsechsundvierzigste")
  , (147, "einhundertsiebenundvierzigste")
  , (148, "einhundertachtundvierzigste")
  , (149, "einhundertneunundvierzigste")
  , (150, "einhundertfünfzigste")
  , (151, "einhunderteinundfünfzigste")
  , (152, "einhundertzweiundfünfzigste")
  , (153, "einhundertdreiundfünfzigste")
  , (154, "einhundertvierundfünfzigste")
  , (155, "einhundertfünfundfünfzigste")
  , (156, "einhundertsechsundfünfzigste")
  , (157, "einhundertsiebenundfünfzigste")
  , (158, "einhundertachtundfünfzigste")
  , (159, "einhundertneunundfünfzigste")
  , (160, "einhundertsechzigste")
  , (161, "einhunderteinundsechzigste")
  , (162, "einhundertzweiundsechzigste")
  , (163, "einhundertdreiundsechzigste")
  , (164, "einhundertvierundsechzigste")
  , (165, "einhundertfünfundsechzigste")
  , (166, "einhundertsechsundsechzigste")
  , (167, "einhundertsiebenundsechzigste")
  , (168, "einhundertachtundsechzigste")
  , (169, "einhundertneunundsechzigste")
  , (170, "einhundertsiebzigste")
  , (171, "einhunderteinundsiebzigste")
  , (172, "einhundertzweiundsiebzigste")
  , (173, "einhundertdreiundsiebzigste")
  , (174, "einhundertvierundsiebzigste")
  , (175, "einhundertfünfundsiebzigste")
  , (176, "einhundertsechsundsiebzigste")
  , (177, "einhundertsiebenundsiebzigste")
  , (178, "einhundertachtundsiebzigste")
  , (179, "einhundertneunundsiebzigste")
  , (180, "einhundertachtzigste")
  , (181, "einhunderteinundachtzigste")
  , (182, "einhundertzweiundachtzigste")
  , (183, "einhundertdreiundachtzigste")
  , (184, "einhundertvierundachtzigste")
  , (185, "einhundertfünfundachtzigste")
  , (186, "einhundertsechsundachtzigste")
  , (187, "einhundertsiebenundachtzigste")
  , (188, "einhundertachtundachtzigste")
  , (189, "einhundertneunundachtzigste")
  , (190, "einhundertneunzigste")
  , (191, "einhunderteinundneunzigste")
  , (192, "einhundertzweiundneunzigste")
  , (193, "einhundertdreiundneunzigste")
  , (194, "einhundertvierundneunzigste")
  , (195, "einhundertfünfundneunzigste")
  , (196, "einhundertsechsundneunzigste")
  , (197, "einhundertsiebenundneunzigste")
  , (198, "einhundertachtundneunzigste")
  , (199, "einhundertneunundneunzigste")
  , (200, "zweihundertste")
  , (233, "zweihundertdreiunddreißigste")
  , (377, "dreihundertsiebenundsiebzigste")
  , (610, "sechshundertzehnte")
  , (987, "neunhundertsiebenundachtzigste")
  , (1597, "eintausendfünfhundertsiebenundneunzigste")
  , (2584, "zweitausendfünfhundertvierundachtzigste")
  , (4181, "viertausendeinhunderteinundachtzigste")
  , (6765, "sechstausendsiebenhundertfünfundsechzigste")
  , (10946, "zehntausendneunhundertsechsundvierzigste")
  , (17711, "siebzehntausendsiebenhundertelfte")
  , (28657, "achtundzwanzigtausendsechshundertsiebenundfünfzigste")
  , (46368, "sechsundvierzigtausenddreihundertachtundsechzigste")
  , (75025, "fünfundsiebzigtausendfünfundzwanzigste")
  , (121393, "einhunderteinundzwanzigtausenddreihundertdreiundneunzigste")
  , (196418, "einhundertsechsundneunzigtausendvierhundertachtzehnte")
  , (317811, "dreihundertsiebzehntausendachthundertelfte")
  , (514229, "fünfhundertvierzehntausendzweihundertneunundzwanzigste")
  , (832040, "achthundertzweiunddreißigtausendvierzigste")
  , (1346269, "eine million dreihundertsechsundvierzigtausendzweihundertneunundsechzigste")
  , (2178309, "zwei millionen einhundertachtundsiebzigtausenddreihundertneunte")
  , (3524578, "drei millionen fünfhundertvierundzwanzigtausendfünfhundertachtundsiebzigste")
  , (5702887, "fünf millionen siebenhundertzweitausendachthundertsiebenundachtzigste")
  , (9227465, "neun millionen zweihundertsiebenundzwanzigtausendvierhundertfünfundsechzigste")
  , (14930352, "vierzehn millionen neunhundertdreißigtausenddreihundertzweiundfünfzigste")
  , (24157817, "vierundzwanzig millionen einhundertsiebenundfünfzigtausendachthundertsiebzehnte")
  , (39088169, "neununddreißig millionen achtundachtzigtausendeinhundertneunundsechzigste")
  , (63245986, "dreiundsechzig millionen zweihundertfünfundvierzigtausendneunhundertsechsundachtzigste")
  , (102334155, "einhundertzwei millionen dreihundertvierunddreißigtausendeinhundertfünfundfünfzigste")
  , (165580141, "einhundertfünfundsechzig millionen fünfhundertachtzigtausendeinhunderteinundvierzigste")
  , (267914296, "zweihundertsiebenundsechzig millionen neunhundertvierzehntausendzweihundertsechsundneunzigste")
  , (433494437, "vierhundertdreiunddreißig millionen vierhundertvierundneunzigtausendvierhundertsiebenunddreißigste")
  , (701408733, "siebenhunderteins millionen vierhundertachttausendsiebenhundertdreiunddreißigste")
  , (1134903170, "eine milliard einhundertvierunddreißig millionen neunhundertdreitausendeinhundertsiebzigste")
  , (1836311903, "eine milliard achthundertsechsunddreißig millionen dreihundertelftausendneunhundertdritte")
  , (2971215073, "zwei milliarden neunhunderteinundsiebzig millionen zweihundertfünfzehntausenddreiundsiebzigste")
  , (4807526976, "vier milliarden achthundertsieben millionen fünfhundertsechsundzwanzigtausendneunhundertsechsundsiebzigste")
  , (7778742049, "sieben milliarden siebenhundertachtundsiebzig millionen siebenhundertzweiundvierzigtausendneunundvierzigste")
  , (12586269025, "zwölf milliarden fünfhundertsechsundachtzig millionen zweihundertneunundsechzigtausendfünfundzwanzigste")
  , (20365011074, "zwanzig milliarden dreihundertfünfundsechzig millionen elftausendvierundsiebzigste")
  , (32951280099, "zweiunddreißig milliarden neunhunderteinundfünfzig millionen zweihundertachtzigtausendneunundneunzigste")
  , (53316291173, "dreiundfünfzig milliarden dreihundertsechzehn millionen zweihunderteinundneunzigtausendeinhundertdreiundsiebzigste")
  , (86267571272, "sechsundachtzig milliarden zweihundertsiebenundsechzig millionen fünfhunderteinundsiebzigtausendzweihundertzweiundsiebzigste")
  , (139583862445, "einhundertneununddreißig milliarden fünfhundertdreiundachtzig millionen achthundertzweiundsechzigtausendvierhundertfünfundvierzigste")
  , (225851433717, "zweihundertfünfundzwanzig milliarden achthunderteinundfünfzig millionen vierhundertdreiunddreißigtausendsiebenhundertsiebzehnte")
  , (365435296162, "dreihundertfünfundsechzig milliarden vierhundertfünfunddreißig millionen zweihundertsechsundneunzigtausendeinhundertzweiundsechzigste")
  , (591286729879, "fünfhunderteinundneunzig milliarden zweihundertsechsundachtzig millionen siebenhundertneunundzwanzigtausendachthundertneunundsiebzigste")
  , (956722026041, "neunhundertsechsundfünfzig milliarden siebenhundertzweiundzwanzig millionen sechsundzwanzigtausendeinundvierzigste")
  , (1548008755920, "eine billion fünfhundertachtundvierzig milliarden acht millionen siebenhundertfünfundfünfzigtausendneunhundertzwanzigste")
  , (2504730781961, "zwei billionen fünfhundertvier milliarden siebenhundertdreißig millionen siebenhunderteinundachtzigtausendneunhunderteinundsechzigste")
  , (4052739537881, "vier billionen zweiundfünfzig milliarden siebenhundertneununddreißig millionen fünfhundertsiebenunddreißigtausendachthunderteinundachtzigste")
  , (6557470319842, "sechs billionen fünfhundertsiebenundfünfzig milliarden vierhundertsiebzig millionen dreihundertneunzehntausendachthundertzweiundvierzigste")
  , (10610209857723, "zehn billionen sechshundertzehn milliarden zweihundertneun millionen achthundertsiebenundfünfzigtausendsiebenhundertdreiundzwanzigste")
  , (17167680177565, "siebzehn billionen einhundertsiebenundsechzig milliarden sechshundertachtzig millionen einhundertsiebenundsiebzigtausendfünfhundertfünfundsechzigste")
  , (27777890035288, "siebenundzwanzig billionen siebenhundertsiebenundsiebzig milliarden achthundertneunzig millionen fünfunddreißigtausendzweihundertachtundachtzigste")
  , (44945570212853, "vierundvierzig billionen neunhundertfünfundvierzig milliarden fünfhundertsiebzig millionen zweihundertzwölftausendachthundertdreiundfünfzigste")
  , (72723460248141, "zweiundsiebzig billionen siebenhundertdreiundzwanzig milliarden vierhundertsechzig millionen zweihundertachtundvierzigtausendeinhunderteinundvierzigste")
  , (117669030460994, "einhundertsiebzehn billionen sechshundertneunundsechzig milliarden dreißig millionen vierhundertsechzigtausendneunhundertvierundneunzigste")
  , (190392490709135, "einhundertneunzig billionen dreihundertzweiundneunzig milliarden vierhundertneunzig millionen siebenhundertneuntausendeinhundertfünfunddreißigste")
  , (308061521170129, "dreihundertacht billionen einundsechzig milliarden fünfhunderteinundzwanzig millionen einhundertsiebzigtausendeinhundertneunundzwanzigste")
  , (498454011879264, "vierhundertachtundneunzig billionen vierhundertvierundfünfzig milliarden elf millionen achthundertneunundsiebzigtausendzweihundertvierundsechzigste")
  , (806515533049393, "achthundertsechs billionen fünfhundertfünfzehn milliarden fünfhundertdreiunddreißig millionen neunundvierzigtausenddreihundertdreiundneunzigste")
  , (1304969544928657, "eine billiard dreihundertvier billionen neunhundertneunundsechzig milliarden fünfhundertvierundvierzig millionen neunhundertachtundzwanzigtausendsechshundertsiebenundfünfzigste")
  , (2111485077978050, "zwei billiarden einhundertelf billionen vierhundertfünfundachtzig milliarden siebenundsiebzig millionen neunhundertachtundsiebzigtausendfünfzigste")
  , (3416454622906707, "drei billiarden vierhundertsechzehn billionen vierhundertvierundfünfzig milliarden sechshundertzweiundzwanzig millionen neunhundertsechstausendsiebenhundertsiebte")
  , (5527939700884757, "fünf billiarden fünfhundertsiebenundzwanzig billionen neunhundertneununddreißig milliarden siebenhundert millionen achthundertvierundachtzigtausendsiebenhundertsiebenundfünfzigste")
  , (8944394323791464, "acht billiarden neunhundertvierundvierzig billionen dreihundertvierundneunzig milliarden dreihundertdreiundzwanzig millionen siebenhunderteinundneunzigtausendvierhundertvierundsechzigste")
  , (14472334024676221, "vierzehn billiarden vierhundertzweiundsiebzig billionen dreihundertvierunddreißig milliarden vierundzwanzig millionen sechshundertsechsundsiebzigtausendzweihunderteinundzwanzigste")
  , (23416728348467685, "dreiundzwanzig billiarden vierhundertsechzehn billionen siebenhundertachtundzwanzig milliarden dreihundertachtundvierzig millionen vierhundertsiebenundsechzigtausendsechshundertfünfundachtzigste")
  , (37889062373143906, "siebenunddreißig billiarden achthundertneunundachtzig billionen zweiundsechzig milliarden dreihundertdreiundsiebzig millionen einhundertdreiundvierzigtausendneunhundertsechste")
  , (61305790721611591, "einundsechzig billiarden dreihundertfünf billionen siebenhundertneunzig milliarden siebenhunderteinundzwanzig millionen sechshundertelftausendfünfhunderteinundneunzigste")
  , (99194853094755497, "neunundneunzig billiarden einhundertvierundneunzig billionen achthundertdreiundfünfzig milliarden vierundneunzig millionen siebenhundertfünfundfünfzigtausendvierhundertsiebenundneunzigste")
  , (160500643816367088, "einhundertsechzig billiarden fünfhundert billionen sechshundertdreiundvierzig milliarden achthundertsechzehn millionen dreihundertsiebenundsechzigtausendachtundachtzigste")
  , (259695496911122585, "zweihundertneunundfünfzig billiarden sechshundertfünfundneunzig billionen vierhundertsechsundneunzig milliarden neunhundertelf millionen einhundertzweiundzwanzigtausendfünfhundertfünfundachtzigste")
  , (420196140727489673, "vierhundertzwanzig billiarden einhundertsechsundneunzig billionen einhundertvierzig milliarden siebenhundertsiebenundzwanzig millionen vierhundertneunundachtzigtausendsechshundertdreiundsiebzigste")
  , (679891637638612258, "sechshundertneunundsiebzig billiarden achthunderteinundneunzig billionen sechshundertsiebenunddreißig milliarden sechshundertachtunddreißig millionen sechshundertzwölftausendzweihundertachtundfünfzigste")
  , (1100087778366101931, "eine trillion einhundert billiarden siebenundachtzig billionen siebenhundertachtundsiebzig milliarden dreihundertsechsundsechzig millionen einhunderteinstausendneunhunderteinunddreißigste")
  , (1779979416004714189, "eine trillion siebenhundertneunundsiebzig billiarden neunhundertneunundsiebzig billionen vierhundertsechzehn milliarden vier millionen siebenhundertvierzehntausendeinhundertneunundachtzigste")
  , (2880067194370816120, "zwei trillionen achthundertachtzig billiarden siebenundsechzig billionen einhundertvierundneunzig milliarden dreihundertsiebzig millionen achthundertsechzehntausendeinhundertzwanzigste")
  , (4660046610375530309, "vier trillionen sechshundertsechzig billiarden sechsundvierzig billionen sechshundertzehn milliarden dreihundertfünfundsiebzig millionen fünfhundertdreißigtausenddreihundertneunte")
  , (7540113804746346429, "sieben trillionen fünfhundertvierzig billiarden einhundertdreizehn billionen achthundertvier milliarden siebenhundertsechsundvierzig millionen dreihundertsechsundvierzigtausendvierhundertneunundzwanzigste")
  , (12200160415121876738, "zwölf trillionen zweihundert billiarden einhundertsechzig billionen vierhundertfünfzehn milliarden einhunderteinundzwanzig millionen achthundertsechsundsiebzigtausendsiebenhundertachtunddreißigste")
  , (19740274219868223167, "neunzehn trillionen siebenhundertvierzig billiarden zweihundertvierundsiebzig billionen zweihundertneunzehn milliarden achthundertachtundsechzig millionen zweihundertdreiundzwanzigtausendeinhundertsiebenundsechzigste")
  , (31940434634990099905, "einunddreißig trillionen neunhundertvierzig billiarden vierhundertvierunddreißig billionen sechshundertvierunddreißig milliarden neunhundertneunzig millionen neunundneunzigtausendneunhundertfünfte")
  , (51680708854858323072, "einundfünfzig trillionen sechshundertachtzig billiarden siebenhundertacht billionen achthundertvierundfünfzig milliarden achthundertachtundfünfzig millionen dreihundertdreiundzwanzigtausendzweiundsiebzigste")
  , (83621143489848422977, "dreiundachtzig trillionen sechshunderteinundzwanzig billiarden einhundertdreiundvierzig billionen vierhundertneunundachtzig milliarden achthundertachtundvierzig millionen vierhundertzweiundzwanzigtausendneunhundertsiebenundsiebzigste")
  , (135301852344706746049, "einhundertfünfunddreißig trillionen dreihunderteins billiarden achthundertzweiundfünfzig billionen dreihundertvierundvierzig milliarden siebenhundertsechs millionen siebenhundertsechsundvierzigtausendneunundvierzigste")
  , (218922995834555169026, "zweihundertachtzehn trillionen neunhundertzweiundzwanzig billiarden neunhundertfünfundneunzig billionen achthundertvierunddreißig milliarden fünfhundertfünfundfünfzig millionen einhundertneunundsechzigtausendsechsundzwanzigste")
  , (354224848179261915075, "dreihundertvierundfünfzig trillionen zweihundertvierundzwanzig billiarden achthundertachtundvierzig billionen einhundertneunundsiebzig milliarden zweihunderteinundsechzig millionen neunhundertfünfzehntausendfünfundsiebzigste")
  , (573147844013817084101, "fünfhundertdreiundsiebzig trillionen einhundertsiebenundvierzig billiarden achthundertvierundvierzig billionen dreizehn milliarden achthundertsiebzehn millionen vierundachtzigtausendeinhunderterste")
  , (927372692193078999176, "neunhundertsiebenundzwanzig trillionen dreihundertzweiundsiebzig billiarden sechshundertzweiundneunzig billionen einhundertdreiundneunzig milliarden achtundsiebzig millionen neunhundertneunundneunzigtausendeinhundertsechsundsiebzigste")
  , (1500520536206896083277, "eine trilliard fünfhundert trillionen fünfhundertzwanzig billiarden fünfhundertsechsunddreißig billionen zweihundertsechs milliarden achthundertsechsundneunzig millionen dreiundachtzigtausendzweihundertsiebenundsiebzigste")
  , (2427893228399975082453, "zwei trilliarden vierhundertsiebenundzwanzig trillionen achthundertdreiundneunzig billiarden zweihundertachtundzwanzig billionen dreihundertneunundneunzig milliarden neunhundertfünfundsiebzig millionen zweiundachtzigtausendvierhundertdreiundfünfzigste")
  , (3928413764606871165730, "drei trilliarden neunhundertachtundzwanzig trillionen vierhundertdreizehn billiarden siebenhundertvierundsechzig billionen sechshundertsechs milliarden achthunderteinundsiebzig millionen einhundertfünfundsechzigtausendsiebenhundertdreißigste")
  , (6356306993006846248183, "sechs trilliarden dreihundertsechsundfünfzig trillionen dreihundertsechs billiarden neunhundertdreiundneunzig billionen sechs milliarden achthundertsechsundvierzig millionen zweihundertachtundvierzigtausendeinhundertdreiundachtzigste")
  , (10284720757613717413913, "zehn trilliarden zweihundertvierundachtzig trillionen siebenhundertzwanzig billiarden siebenhundertsiebenundfünfzig billionen sechshundertdreizehn milliarden siebenhundertsiebzehn millionen vierhundertdreizehntausendneunhundertdreizehnte")
  , (16641027750620563662096, "sechzehn trilliarden sechshunderteinundvierzig trillionen siebenundzwanzig billiarden siebenhundertfünfzig billionen sechshundertzwanzig milliarden fünfhundertdreiundsechzig millionen sechshundertzweiundsechzigtausendsechsundneunzigste")
  , (26925748508234281076009, "sechsundzwanzig trilliarden neunhundertfünfundzwanzig trillionen siebenhundertachtundvierzig billiarden fünfhundertacht billionen zweihundertvierunddreißig milliarden zweihunderteinundachtzig millionen sechsundsiebzigtausendneunte")
  , (43566776258854844738105, "dreiundvierzig trilliarden fünfhundertsechsundsechzig trillionen siebenhundertsechsundsiebzig billiarden zweihundertachtundfünfzig billionen achthundertvierundfünfzig milliarden achthundertvierundvierzig millionen siebenhundertachtunddreißigtausendeinhundertfünfte")
  , (70492524767089125814114, "siebzig trilliarden vierhundertzweiundneunzig trillionen fünfhundertvierundzwanzig billiarden siebenhundertsiebenundsechzig billionen neunundachtzig milliarden einhundertfünfundzwanzig millionen achthundertvierzehntausendeinhundertvierzehnte")
  , (114059301025943970552219, "einhundertvierzehn trilliarden neunundfünfzig trillionen dreihunderteins billiarden fünfundzwanzig billionen neunhundertdreiundvierzig milliarden neunhundertsiebzig millionen fünfhundertzweiundfünfzigtausendzweihundertneunzehnte")
  , (1000, "tausendste")
  , (10000, "zehntausendste")
  , (100000, "einhunderttausendste")
  , (1000000, "millionste")
  , (10000000, "zehnmillionste")
  , (100000000, "einhundertmillionste")
  , (1000000000, "eine milliardte")
  , (10000000000, "zehnmilliardste")
  , (100000000000, "einhundertmilliardste")
  , (1000000000000, "billionste")
  , (10000000000000, "zehnbillionste")
  , (100000000000000, "einhundertbillionste")
  , (1000000000000000, "eine billiardte")
  , (10000000000000000, "zehnbilliardste")
  , (100000000000000000, "einhundertbilliardste")
  , (1000000000000000000, "trillionste")
  , (10000000000000000000, "zehntrillionste")
  , (100000000000000000000, "einhunderttrillionste")
  , (1000000000000000000000, "eine trilliardte")
  , (10000000000000000000000, "zehntrilliardste")
  , (100000000000000000000000, "einhunderttrilliardste")
  , (1000000000000000000000000, "quadrillionste")
  ]

shortOrdinals :: [(Integer, Text)]
shortOrdinals = [
    (0, "0.")
  , (1, "1.")
  , (2, "2.")
  , (3, "3.")
  , (4, "4.")
  , (5, "5.")
  , (6, "6.")
  , (7, "7.")
  , (8, "8.")
  , (9, "9.")
  , (10, "10.")
  , (11, "11.")
  , (12, "12.")
  , (13, "13.")
  , (14, "14.")
  , (15, "15.")
  , (16, "16.")
  , (17, "17.")
  , (18, "18.")
  , (19, "19.")
  , (20, "20.")
  , (21, "21.")
  , (22, "22.")
  , (23, "23.")
  , (24, "24.")
  , (25, "25.")
  , (26, "26.")
  , (27, "27.")
  , (28, "28.")
  , (29, "29.")
  , (30, "30.")
  , (31, "31.")
  , (32, "32.")
  , (33, "33.")
  , (34, "34.")
  , (35, "35.")
  , (36, "36.")
  , (37, "37.")
  , (38, "38.")
  , (39, "39.")
  , (40, "40.")
  , (41, "41.")
  , (42, "42.")
  , (43, "43.")
  , (44, "44.")
  , (45, "45.")
  , (46, "46.")
  , (47, "47.")
  , (48, "48.")
  , (49, "49.")
  , (50, "50.")
  , (51, "51.")
  , (52, "52.")
  , (53, "53.")
  , (54, "54.")
  , (55, "55.")
  , (56, "56.")
  , (57, "57.")
  , (58, "58.")
  , (59, "59.")
  , (60, "60.")
  , (61, "61.")
  , (62, "62.")
  , (63, "63.")
  , (64, "64.")
  , (65, "65.")
  , (66, "66.")
  , (67, "67.")
  , (68, "68.")
  , (69, "69.")
  , (70, "70.")
  , (71, "71.")
  , (72, "72.")
  , (73, "73.")
  , (74, "74.")
  , (75, "75.")
  , (76, "76.")
  , (77, "77.")
  , (78, "78.")
  , (79, "79.")
  , (80, "80.")
  , (81, "81.")
  , (82, "82.")
  , (83, "83.")
  , (84, "84.")
  , (85, "85.")
  , (86, "86.")
  , (87, "87.")
  , (88, "88.")
  , (89, "89.")
  , (90, "90.")
  , (91, "91.")
  , (92, "92.")
  , (93, "93.")
  , (94, "94.")
  , (95, "95.")
  , (96, "96.")
  , (97, "97.")
  , (98, "98.")
  , (99, "99.")
  , (100, "100.")
  , (101, "101.")
  , (102, "102.")
  , (103, "103.")
  , (104, "104.")
  , (105, "105.")
  , (106, "106.")
  , (107, "107.")
  , (108, "108.")
  , (109, "109.")
  , (110, "110.")
  , (111, "111.")
  , (112, "112.")
  , (113, "113.")
  , (114, "114.")
  , (115, "115.")
  , (116, "116.")
  , (117, "117.")
  , (118, "118.")
  , (119, "119.")
  , (120, "120.")
  , (121, "121.")
  , (122, "122.")
  , (123, "123.")
  , (124, "124.")
  , (125, "125.")
  , (126, "126.")
  , (127, "127.")
  , (128, "128.")
  , (129, "129.")
  , (130, "130.")
  , (131, "131.")
  , (132, "132.")
  , (133, "133.")
  , (134, "134.")
  , (135, "135.")
  , (136, "136.")
  , (137, "137.")
  , (138, "138.")
  , (139, "139.")
  , (140, "140.")
  , (141, "141.")
  , (142, "142.")
  , (143, "143.")
  , (144, "144.")
  , (145, "145.")
  , (146, "146.")
  , (147, "147.")
  , (148, "148.")
  , (149, "149.")
  , (150, "150.")
  , (151, "151.")
  , (152, "152.")
  , (153, "153.")
  , (154, "154.")
  , (155, "155.")
  , (156, "156.")
  , (157, "157.")
  , (158, "158.")
  , (159, "159.")
  , (160, "160.")
  , (161, "161.")
  , (162, "162.")
  , (163, "163.")
  , (164, "164.")
  , (165, "165.")
  , (166, "166.")
  , (167, "167.")
  , (168, "168.")
  , (169, "169.")
  , (170, "170.")
  , (171, "171.")
  , (172, "172.")
  , (173, "173.")
  , (174, "174.")
  , (175, "175.")
  , (176, "176.")
  , (177, "177.")
  , (178, "178.")
  , (179, "179.")
  , (180, "180.")
  , (181, "181.")
  , (182, "182.")
  , (183, "183.")
  , (184, "184.")
  , (185, "185.")
  , (186, "186.")
  , (187, "187.")
  , (188, "188.")
  , (189, "189.")
  , (190, "190.")
  , (191, "191.")
  , (192, "192.")
  , (193, "193.")
  , (194, "194.")
  , (195, "195.")
  , (196, "196.")
  , (197, "197.")
  , (198, "198.")
  , (199, "199.")
  , (200, "200.")
  , (233, "233.")
  , (377, "377.")
  , (610, "610.")
  , (987, "987.")
  , (1597, "1597.")
  , (2584, "2584.")
  , (4181, "4181.")
  , (6765, "6765.")
  , (10946, "10946.")
  , (17711, "17711.")
  , (28657, "28657.")
  , (46368, "46368.")
  , (75025, "75025.")
  , (121393, "121393.")
  , (196418, "196418.")
  , (317811, "317811.")
  , (514229, "514229.")
  , (832040, "832040.")
  , (1346269, "1346269.")
  , (2178309, "2178309.")
  , (3524578, "3524578.")
  , (5702887, "5702887.")
  , (9227465, "9227465.")
  , (14930352, "14930352.")
  , (24157817, "24157817.")
  , (39088169, "39088169.")
  , (63245986, "63245986.")
  , (102334155, "102334155.")
  , (165580141, "165580141.")
  , (267914296, "267914296.")
  , (433494437, "433494437.")
  , (701408733, "701408733.")
  , (1134903170, "1134903170.")
  , (1836311903, "1836311903.")
  , (2971215073, "2971215073.")
  , (4807526976, "4807526976.")
  , (7778742049, "7778742049.")
  , (12586269025, "12586269025.")
  , (20365011074, "20365011074.")
  , (32951280099, "32951280099.")
  , (53316291173, "53316291173.")
  , (86267571272, "86267571272.")
  , (139583862445, "139583862445.")
  , (225851433717, "225851433717.")
  , (365435296162, "365435296162.")
  , (591286729879, "591286729879.")
  , (956722026041, "956722026041.")
  , (1548008755920, "1548008755920.")
  , (2504730781961, "2504730781961.")
  , (4052739537881, "4052739537881.")
  , (6557470319842, "6557470319842.")
  , (10610209857723, "10610209857723.")
  , (17167680177565, "17167680177565.")
  , (27777890035288, "27777890035288.")
  , (44945570212853, "44945570212853.")
  , (72723460248141, "72723460248141.")
  , (117669030460994, "117669030460994.")
  , (190392490709135, "190392490709135.")
  , (308061521170129, "308061521170129.")
  , (498454011879264, "498454011879264.")
  , (806515533049393, "806515533049393.")
  , (1304969544928657, "1304969544928657.")
  , (2111485077978050, "2111485077978050.")
  , (3416454622906707, "3416454622906707.")
  , (5527939700884757, "5527939700884757.")
  , (8944394323791464, "8944394323791464.")
  , (14472334024676221, "14472334024676221.")
  , (23416728348467685, "23416728348467685.")
  , (37889062373143906, "37889062373143906.")
  , (61305790721611591, "61305790721611591.")
  , (99194853094755497, "99194853094755497.")
  , (160500643816367088, "160500643816367088.")
  , (259695496911122585, "259695496911122585.")
  , (420196140727489673, "420196140727489673.")
  , (679891637638612258, "679891637638612258.")
  , (1100087778366101931, "1100087778366101931.")
  , (1779979416004714189, "1779979416004714189.")
  , (2880067194370816120, "2880067194370816120.")
  , (4660046610375530309, "4660046610375530309.")
  , (7540113804746346429, "7540113804746346429.")
  , (12200160415121876738, "12200160415121876738.")
  , (19740274219868223167, "19740274219868223167.")
  , (31940434634990099905, "31940434634990099905.")
  , (51680708854858323072, "51680708854858323072.")
  , (83621143489848422977, "83621143489848422977.")
  , (135301852344706746049, "135301852344706746049.")
  , (218922995834555169026, "218922995834555169026.")
  , (354224848179261915075, "354224848179261915075.")
  , (573147844013817084101, "573147844013817084101.")
  , (927372692193078999176, "927372692193078999176.")
  , (1500520536206896083277, "1500520536206896083277.")
  , (2427893228399975082453, "2427893228399975082453.")
  , (3928413764606871165730, "3928413764606871165730.")
  , (6356306993006846248183, "6356306993006846248183.")
  , (10284720757613717413913, "10284720757613717413913.")
  , (16641027750620563662096, "16641027750620563662096.")
  , (26925748508234281076009, "26925748508234281076009.")
  , (43566776258854844738105, "43566776258854844738105.")
  , (70492524767089125814114, "70492524767089125814114.")
  , (114059301025943970552219, "114059301025943970552219.")
  , (1000, "1000.")
  , (10000, "10000.")
  , (100000, "100000.")
  , (1000000, "1000000.")
  , (10000000, "10000000.")
  , (100000000, "100000000.")
  , (1000000000, "1000000000.")
  , (10000000000, "10000000000.")
  , (100000000000, "100000000000.")
  , (1000000000000, "1000000000000.")
  , (10000000000000, "10000000000000.")
  , (100000000000000, "100000000000000.")
  , (1000000000000000, "1000000000000000.")
  , (10000000000000000, "10000000000000000.")
  , (100000000000000000, "100000000000000000.")
  , (1000000000000000000, "1000000000000000000.")
  , (10000000000000000000, "10000000000000000000.")
  , (100000000000000000000, "100000000000000000000.")
  , (1000000000000000000000, "1000000000000000000000.")
  , (10000000000000000000000, "10000000000000000000000.")
  , (100000000000000000000000, "100000000000000000000000.")
  , (1000000000000000000000000, "1000000000000000000000000.")
  ]
